acsv: Algorithms for analytic combinatorics in several variables
================================================================

Description
-----------

SageMath package with algorithms for analytic combinatorics in several variables

License
-------

MIT License

Upstream Contact
----------------

- https://pypi.org/project/sage-acsv/
- https://github.com/passagemath/passagemath-pkg-acsv
